+++
title = "Sub/superscripts don't require braces"
tags = ["export-option", "superscripts", "subscripts"]
draft = false
+++

## Following text will export `_..` as subscript and `^..` as superscript {#following-text-will-export-dot-dot-as-subscript-and-dot-dot-as-superscript}

a<sub>b</sub> a<sub>bc</sub> a<sup>b</sup> a<sup>bc</sup>


## Following text will export `_{..}` as subscript and `^{..}` as superscript {#following-text-will-export-dot-dot-as-subscript-and-dot-dot-as-superscript}

a<sub>b</sub> a<sub>bc</sub> a<sup>b</sup> a<sup>bc</sup>
